//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[RegularHandPattern](index.md)/[jyantou](jyantou.md)

# jyantou

[common]\
open override val [jyantou](jyantou.md): [Tile](../../mahjongutils.models/-tile/index.md)?

雀头
